==> super_resolution-0.1.3.tar.gz: super_resolution-0.1.3/setup.py <==
#!/usr/bin/env python3

import os
from setuptools import setup

# get key package details from super_resolution/__version__.py
about = {}  # type: ignore
here = os.path.abspath(os.path.dirname(__file__))
with open(os.path.join(here, 'super_resolution', '__version__.py')) as f:
    exec(f.read(), about)

# load the README file and use it as the long_description for PyPI
with open('README.md', 'r') as f:
    readme = f.read()

# package configuration - for reference see:
# https://setuptools.readthedocs.io/en/latest/setuptools.html#id9
setup(
    name=about['__title__'],
    description=about['__description__'],
    long_description=readme,
    long_description_content_type='text/markdown',
    version=about['__version__'],
    author=about['__author__'],
    author_email=about['__author_email__'],
    url=about['__url__'],
    packages=['super_resolution'],
    package_dir={"": '.'},
    include_package_data=True,
    python_requires=">=3.6.*",
    install_requires=['imageio', 'tensorflow>=2.3', 'tensorflow-cpu>=2.3'],
    #install_requires=['imageio'],
    license=about['__license__'],
    zip_safe=False,
    entry_points={ 'console_scripts': ['super_resolution=super_resolution.entry_points:main'], },
    classifiers=[
        'Development Status :: 3 - Alpha',
        'Intended Audience :: Developers',
        'Environment :: Console',
        'Intended Audience :: Developers',
        'Intended Audience :: Education',
        'Intended Audience :: Information Technology',
        'Intended Audience :: Science/Research',
        'License :: OSI Approved :: BSD License',
        'Operating System :: MacOS',
        'Operating System :: Microsoft :: Windows',
        'Operating System :: POSIX',
        'Operating System :: Unix',
        'Programming Language :: Python :: 3.6',
        'Programming Language :: Python :: 3.7',
        'Programming Language :: Python :: 3.8',
        'Programming Language :: Python :: 3.9',
        'Topic :: Scientific/Engineering',
        'Topic :: Scientific/Engineering :: Artificial Intelligence',
        'Topic :: Multimedia :: Graphics',
        'Topic :: Multimedia :: Graphics :: Graphics Conversion',
    ],
    keywords='super-resolution',
)

==> super_resolution-0.2.1.tar.gz: super_resolution-0.2.1/setup.py <==
#!/usr/bin/env python3

import os
from setuptools import setup

# get key package details from super_resolution/__version__.py
about = {}  # type: ignore
here = os.path.abspath(os.path.dirname(__file__))
with open(os.path.join(here, 'super_resolution', '__version__.py')) as f:
    exec(f.read(), about)

# load the README file and use it as the long_description for PyPI
with open('README.md', 'r') as f:
    readme = f.read()

# package configuration - for reference see:
# https://setuptools.readthedocs.io/en/latest/setuptools.html#id9
setup(
    name=about['__title__'],
    description=about['__description__'],
    long_description=readme,
    long_description_content_type='text/markdown',
    version=about['__version__'],
    author=about['__author__'],
    author_email=about['__author_email__'],
    url=about['__url__'],
    packages=['super_resolution'],
    package_dir={"": '.', "model1":'./super_resolution/resources/cartoon_model/*', "model2":'./super_resolution/resources/cartoon_model_8x/*'},
    include_package_data=True,
    python_requires=">=3.6.*",
    install_requires=['imageio', 'tensorflow>=2.3', 'tensorflow-cpu>=2.3'],
    #install_requires=['imageio'],
    license=about['__license__'],
    zip_safe=False,
    entry_points={ 'console_scripts': ['super_resolution=super_resolution.entry_points:main'], },
    classifiers=[
        'Development Status :: 3 - Alpha',
        'Intended Audience :: Developers',
        'Environment :: Console',
        'Intended Audience :: Developers',
        'Intended Audience :: Education',
        'Intended Audience :: Information Technology',
        'Intended Audience :: Science/Research',
        'License :: OSI Approved :: BSD License',
        'Operating System :: MacOS',
        'Operating System :: Microsoft :: Windows',
        'Operating System :: POSIX',
        'Operating System :: Unix',
        'Programming Language :: Python :: 3.6',
        'Programming Language :: Python :: 3.7',
        'Programming Language :: Python :: 3.8',
        'Programming Language :: Python :: 3.9',
        'Topic :: Scientific/Engineering',
        'Topic :: Scientific/Engineering :: Artificial Intelligence',
        'Topic :: Multimedia :: Graphics',
        'Topic :: Multimedia :: Graphics :: Graphics Conversion',
    ],
    keywords='super-resolution',
)
